uconfig
=======

uconfig is a simple parser for unix style configurations written in pure python.

Demos, examples and test will follow soon.

At the moment this repository/package should be considered as private.
